@@ -12,10 +12,11 @@ from (
     select x.indexrelid::regclass as idx,
         x.indrelid::regclass as table_name,
         (x.indrelid::text || ' ' || x.indclass::text || ' ' || x.indkey::text || ' ' ||
-         coalesce(pg_get_expr(x.indexprs, x.indrelid), '') || e' ' ||
+         x.indcollation::text || e' ' ||
+         coalesce(pg_get_expr(x.indexprs, x.indrelid), '') || ' ' ||
          coalesce(pg_get_expr(x.indpred, x.indrelid), '')) as key
     from pg_catalog.pg_index x
-             join pg_catalog.pg_stat_all_indexes psai on x.indexrelid = psai.indexrelid
+        join pg_catalog.pg_stat_all_indexes psai on x.indexrelid = psai.indexrelid
     where psai.schemaname = :schema_name_param::text
 ) sub
 group by table_name, key
